cmd

package
v0.0.0-...-9e19654 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 15, 2021 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

const BUILD_PATH = "~/.cache/kbuild"

Variables

This section is empty.

Functions

func Execute

func Execute() error

func GetHostArch

func GetHostArch() string

Types

type KbuildConfig

type KbuildConfig struct {
	Common   *Profile            `yaml:"Common"`
	Profiles map[string]*Profile `yaml:"Profiles"`
}

type Profile

type Profile struct {
	SrcPath      string            `yaml:"srcdir"`
	BuildDir     string            `yaml:"builddir"`
	Arch         string            `yaml:"arch"`
	CC           string            `yaml:"cc"`
	CrossCompile string            `yaml:"cross_compile"`
	Pull         bool              `yaml:"pull"`
	BaseConfig   string            `yaml:"baseconfig"`
	Configs      []string          `yaml:"configs"`
	Modules      []string          `yaml:"module_paths"`
	Environment  map[string]string `yaml:"env"`
	NumJobs      int               `yaml:"jobs"`
	// contains filtered or unexported fields
}

func (*Profile) Build

func (p *Profile) Build(build_args []string) error

func (*Profile) Config

func (p *Profile) Config(skip_base bool) error

func (*Profile) Setenv

func (p *Profile) Setenv(key, val string, overwrite bool)

Setenv sets the build environment variables with an option to not overwrite existing environment variables.

func (*Profile) Setup

func (p *Profile) Setup() error

setup does some sanity checks and creates the build directory

Jump to